@@ -1,19 +1,18 @@
 /*
  * Copyright © 2018–2019 Egmont Koblinger
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
+ * This library is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published
+ * by the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 /*
@@ -259,7 +258,7 @@ BidiRunner::explicit_line_shape(vte::grid::row_t row)
 
                 /* Convenience stuff, we no longer need the auto-growing GArray wrapper. */
                 count = fribidi_chars_array->len;
-                fribidi_chars = (FriBidiChar *) fribidi_chars_array->data;
+                fribidi_chars = reinterpret_cast<FriBidiChar*>(fribidi_chars_array->data);
 
                 /* Run the BiDi algorithm on the paragraph to get the embedding levels. */
                 fribidi_chartypes = g_newa (FriBidiCharType, count);
@@ -559,9 +558,9 @@ BidiRunner::implicit_paragraph(vte::grid::row_t start, vte::grid::row_t end, boo
 
         /* Convenience stuff, we no longer need the auto-growing GArray wrapper. */
         count = fribidi_chars_array->len;
-        fribidi_chars = (FriBidiChar *) fribidi_chars_array->data;
-        fribidi_map = (FriBidiStrIndex *) fribidi_map_array->data;
-        fribidi_to_term = (FriBidiStrIndex *) fribidi_to_term_array->data;
+        fribidi_chars = reinterpret_cast<FriBidiChar*>(fribidi_chars_array->data);
+        fribidi_map = reinterpret_cast<FriBidiStrIndex*>(fribidi_map_array->data);
+        fribidi_to_term = reinterpret_cast<FriBidiStrIndex*>(fribidi_to_term_array->data);
 
         /* Run the BiDi algorithm on the paragraph to get the embedding levels. */
         fribidi_chartypes = g_newa (FriBidiCharType, count);
