@@ -2,18 +2,18 @@
  * Copyright © 2015 David Herrmann <dh.herrmann@gmail.com>
  * Copyright © 2017, 2018 Christian Persch
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 3 of the License, or (at your option) any later version.
+ * This library is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published
+ * by the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -163,13 +163,23 @@ static unsigned int
 vte_parse_host_control(vte_seq_t const* seq)
 {
         switch (seq->terminator) {
-#define _VTE_SEQ(cmd,type,f,pi,ni,i0) case f: return VTE_CMD_##cmd;
+#define _VTE_SEQ(cmd,type,f,pi,ni,i0,flags) case f: return VTE_CMD_##cmd;
 #include "parser-c01.hh"
 #undef _VTE_SEQ
         default: return VTE_CMD_NONE;
         }
 }
 
+/* ECMA-35 § 14.1 specifies that the final character 7/14 always identifies
+ * an empty set. Note that that this does not apply for DRCS sets (§ 14.4),
+ * since § 13.3.3 says that all the Ft (4/0..7/14) bytes are private-use.
+ */
+static inline constexpr unsigned int
+charset_empty_or_none(uint32_t raw)
+{
+        return raw == 0x7e ? VTE_CHARSET_EMPTY : VTE_CHARSET_NONE;
+}
+
 static unsigned int
 vte_parse_charset_94(uint32_t raw,
                      unsigned int intermediates)
@@ -217,7 +227,7 @@ vte_parse_charset_94(uint32_t raw,
                 break;
         }
 
-        return VTE_CHARSET_NONE;
+        return charset_empty_or_none(raw);
 }
 
 static unsigned int
@@ -237,9 +247,15 @@ vte_parse_charset_94_n(uint32_t raw,
 
         case VTE_SEQ_INTERMEDIATE_SPACE:
                 return VTE_CHARSET_DRCS;
+
+        case VTE_SEQ_INTERMEDIATE_BANG:
+                if (remaining_intermediates == 0 &&
+                    raw < (0x30 + G_N_ELEMENTS(charset_graphic_94_n_with_2_1)))
+                        return charset_graphic_94_n_with_2_1[raw - 0x30];
+                break;
         }
 
-        return VTE_CHARSET_NONE;
+        return charset_empty_or_none(raw);
 }
 
 static unsigned int
@@ -261,7 +277,7 @@ vte_parse_charset_96(uint32_t raw,
                 return VTE_CHARSET_DRCS;
         }
 
-        return VTE_CHARSET_NONE;
+        return charset_empty_or_none(raw);
 }
 
 static unsigned int
@@ -271,7 +287,7 @@ vte_parse_charset_96_n(uint32_t raw,
         if (VTE_SEQ_INTERMEDIATE(intermediates) == VTE_SEQ_INTERMEDIATE_SPACE)
                 return VTE_CHARSET_DRCS;
 
-        return VTE_CHARSET_NONE;
+        return charset_empty_or_none(raw);
 }
 
 static unsigned int
@@ -293,7 +309,6 @@ vte_parse_charset_ocs(uint32_t raw,
                 if (remaining_intermediates == 0 &&
                     raw >= 0x30 && raw < (0x30 + G_N_ELEMENTS(charset_ocs_with_2_0)))
                         return charset_ocs_with_2_0[raw - 0x30];
-                /* Or should this return VTE_CHARSET_DRCS; ? */
                 break;
 
         case VTE_SEQ_INTERMEDIATE_BANG ... VTE_SEQ_INTERMEDIATE_DOT: /* OCS with standard return */
@@ -331,7 +346,7 @@ vte_parse_charset_control(uint32_t raw,
                 break;
         }
 
-        return VTE_CHARSET_NONE;
+        return charset_empty_or_none(raw);
 }
 
 static unsigned int
@@ -346,7 +361,7 @@ vte_parse_host_escape(vte_seq_t const* seq,
         case VTE_SEQ_INTERMEDIATE_NONE:
         case VTE_SEQ_INTERMEDIATE_HASH: {  /* Single control functions */
                 switch (_VTE_SEQ_CODE_ESC(seq->terminator, intermediates)) {
-#define _VTE_SEQ(cmd,type,f,p,ni,i) \
+#define _VTE_SEQ(cmd,type,f,p,ni,i,flags) \
                         case _VTE_SEQ_CODE_ESC(f, VTE_SEQ_INTERMEDIATE_##i): return VTE_CMD_##cmd;
 #include "parser-esc.hh"
 #undef _VTE_SEQ
@@ -453,7 +468,7 @@ static unsigned int
 vte_parse_host_csi(vte_seq_t const* seq)
 {
         switch (_VTE_SEQ_CODE(seq->terminator, seq->intermediates)) {
-#define _VTE_SEQ(cmd,type,f,p,ni,i) \
+#define _VTE_SEQ(cmd,type,f,p,ni,i,flags) \
                 case _VTE_SEQ_CODE(f, _VTE_SEQ_CODE_COMBINE(VTE_SEQ_PARAMETER_##p, VTE_SEQ_INTERMEDIATE_##i)): return VTE_CMD_##cmd;
 #include "parser-csi.hh"
 #undef _VTE_SEQ
@@ -462,11 +477,12 @@ vte_parse_host_csi(vte_seq_t const* seq)
 }
 
 static unsigned int
-vte_parse_host_dcs(vte_seq_t const* seq)
+vte_parse_host_dcs(vte_seq_t const* seq,
+                   unsigned int* flagsptr)
 {
         switch (_VTE_SEQ_CODE(seq->terminator, seq->intermediates)) {
-#define _VTE_SEQ(cmd,type,f,p,ni,i) \
-                case _VTE_SEQ_CODE(f, _VTE_SEQ_CODE_COMBINE(VTE_SEQ_PARAMETER_##p, VTE_SEQ_INTERMEDIATE_##i)): return VTE_CMD_##cmd;
+#define _VTE_SEQ(cmd,type,f,p,ni,i,flags) \
+                case _VTE_SEQ_CODE(f, _VTE_SEQ_CODE_COMBINE(VTE_SEQ_PARAMETER_##p, VTE_SEQ_INTERMEDIATE_##i)): *flagsptr = flags; return VTE_CMD_##cmd;
 #include "parser-dcs.hh"
 #undef _VTE_SEQ
         default: return VTE_CMD_NONE;
@@ -477,7 +493,7 @@ static unsigned int
 vte_parse_host_sci(vte_seq_t const* seq)
 {
         switch (_VTE_SEQ_CODE(seq->terminator, 0)) {
-#define _VTE_SEQ(cmd,type,f,p,ni,i) \
+#define _VTE_SEQ(cmd,type,f,p,ni,i,flags) \
                 case _VTE_SEQ_CODE(f, 0): return VTE_CMD_##cmd;
 #include "parser-sci.hh"
 #undef _VTE_SEQ
@@ -599,9 +615,9 @@ parser_transition(vte_parser_t* parser,
 
 #endif // (inline) functions or macros
 
-/**
- * vte_parser_init() - Initialise parser object
- * @parser: the struct vte_parser
+/*
+ * vte_parser_init:
+ * @parser:
  */
 void
 vte_parser_init(vte_parser_t* parser)
@@ -611,8 +627,8 @@ vte_parser_init(vte_parser_t* parser)
 }
 
 /**
- * vte_parser_deinit() - Deinitialises parser object
- * @parser: parser object to deinitialise
+ * vte_parser_deinit:
+ * @parser:
  */
 void
 vte_parser_deinit(vte_parser_t* parser)
@@ -881,9 +897,12 @@ parser_dcs_consume(vte_parser_t* parser,
 
         parser->seq.type = VTE_SEQ_DCS;
         parser->seq.terminator = raw;
-        parser->seq.command = vte_parse_host_dcs(&parser->seq);
+        parser->seq.st = 0;
 
-        return VTE_SEQ_NONE;
+        auto flags = unsigned{};
+        parser->seq.command = vte_parse_host_dcs(&parser->seq, &flags);
+
+        return (flags & VTE_DISPATCH_UNRIPE) && parser->dispatch_unripe ? VTE_SEQ_DCS : VTE_SEQ_NONE;
 }
 
 static int
@@ -950,7 +969,7 @@ parser_osc(vte_parser_t* parser,
 
         parser->seq.type = VTE_SEQ_OSC;
         parser->seq.command = VTE_CMD_OSC;
-        parser->seq.terminator = raw;
+        parser->seq.st = raw;
 
         return parser->seq.type;
 }
@@ -959,7 +978,8 @@ static int
 parser_dcs(vte_parser_t* parser,
            uint32_t raw)
 {
-        /* parser->seq was already filled in parser_dcs_consume() */
+        /* Most of parser->seq was already filled in parser_dcs_consume() */
+        parser->seq.st = raw;
 
         vte_seq_string_finish(&parser->seq.arg_str);
 
@@ -1444,3 +1464,66 @@ vte_parser_reset(vte_parser_t* parser)
 {
         parser_transition(parser, 0, STATE_GROUND, ACTION_IGNORE);
 }
+
+/*
+ * vte_parser_set_dispatch_unripe:
+ * @parser: a #vte_parser_t
+ * @enable:
+ *
+ * Enables or disables dispatch of unripe DCS sequences.
+ * If enabled, known DCS sequences with the %VTE_DISPATCH_UNRIPE
+ * flag will be dispatched when the Final character is received,
+ * instead of when the control string terminator (ST) is received.
+ * The application handling the unripe DCS sequence may then
+ * either
+ * * do nothing; in this case the DCS sequence will be dispatched
+ *   again when the control string was fully received. Ripe and
+ *   unripe sequences can be distinguished by the value of
+ *   parser.seq.st which will be 0 for an unripe sequence and
+ *   either 0x5c (C0 ST) or 0x9c (C1 ST) for a ripe sequence. Or
+ * * call vte_parser_ignore_until_st(); in this case the DCS
+ *   sequence will be ignored until after the ST (or an other
+ *   character that aborts the control string) has been
+ *   received; or
+ * * switch to a different parser (e.g. DECSIXEL) to parse the
+ *   control string directly on-the-fly. Note that in this case,
+ *   the subparser should take care to handle C0 and C1 controls
+ *   the same way as this parser would.
+ */
+void
+vte_parser_set_dispatch_unripe(vte_parser_t* parser,
+                               bool enable)
+{
+        parser->dispatch_unripe = enable;
+}
+
+/*
+ * vte_parser_ignore_until_st:
+ * @parser: a #vte_parser_t
+ *
+ * When used on an unrip %VTE_SEQ_DCS sequence, makes the
+ * parser ignore everything until the ST is received (or
+ * the DCS is aborted by the usual other means).
+ *
+ * Note that there is some inconsistencies here:
+ *
+ * * SUB aborts the DCS in our parser, but e.g. a DECSIXEL
+ *   parser will handle it as if 3/15 was received.
+ *
+ * * the ST terminating the DCS will be dispatched as an ST
+ *   sequence, instead of producing an IGNORE sequence
+ *   (this is easily fixable but would slightly complicate
+ *   the parser for no actual gain).
+ */
+void
+vte_parser_ignore_until_st(vte_parser_t* parser)
+{
+        switch (parser->state) {
+        case STATE_DCS_PASS:
+                parser_transition_no_action(parser, 0, STATE_DCS_IGNORE);
+                break;
+        default:
+                g_assert_not_reached();
+                break;
+        }
+}
