@@ -25,7 +25,7 @@
 #include <vte/vte.h>
 #include "vteptyinternal.hh"
 #include "vtespawn.hh"
-#include "debug.hh"
+#include "debug.h"
 #include "reaper.hh"
 
 #include <assert.h>
@@ -39,7 +39,7 @@
 
 #include "glib-glue.hh"
 
-#if WITH_SYSTEMD
+#ifdef WITH_SYSTEMD
 #include "systemd.hh"
 #endif
 
@@ -91,15 +91,6 @@ make_pipe(int flags,
           vte::libc::FD& write_fd,
           vte::glib::Error& error)
 {
-#if !GLIB_CHECK_VERSION(2, 78, 0)
-        if constexpr (O_CLOEXEC != FD_CLOEXEC) {
-                if (flags & O_CLOEXEC) {
-                        flags &= ~O_CLOEXEC;
-                        flags |= FD_CLOEXEC;
-                }
-        }
-#endif // !glib 2.78
-
         int fds[2] = { -1, -1 };
         if (!g_unix_open_pipe(fds, flags, error))
                 return false;
@@ -152,7 +143,7 @@ read_ints(int fd,
 
         auto bytes = size_t{0};
         while (true) {
-                if (bytes >= sizeof(int) * n_ints_in_buf)
+                if (bytes >= sizeof(int)*2)
                         break; /* give up, who knows what happened, should not be
                                 * possible.
                                 */
@@ -265,15 +256,6 @@ merge_environ(char** envp /* consumed */,
                 g_strfreev(envp);
         }
 
-        // Make our terminfo available
-        if (auto const tidirs = (char const*)g_hash_table_lookup(table, "TERMINFO_DIRS");
-            tidirs && tidirs[0])
-                g_hash_table_replace(table, g_strdup("TERMINFO_DIRS"),
-                                     g_strdup_printf("%s:%s", TERMINFODIR, tidirs));
-        else
-                g_hash_table_replace(table, g_strdup("TERMINFO_DIRS"),
-                                     g_strdup(TERMINFODIR));
-
         /* Always set this ourself, not allowing replacing from envp */
         g_hash_table_replace(table, g_strdup("VTE_VERSION"), g_strdup_printf("%u", VTE_VERSION_NUMERIC));
         g_hash_table_replace(table, g_strdup("COLORTERM"), g_strdup("truecolor"));
@@ -339,31 +321,28 @@ SpawnContext::exec(vte::libc::FD& child_report_error_pipe_write,
          * when the exec succeeds!
          */
 
-#if VTE_DEBUG
-        _VTE_DEBUG_IF(vte::debug::category::MISC) {
-                vte::debug::println("Spawning command:");
+        _VTE_DEBUG_IF(VTE_DEBUG_MISC) {
+                g_printerr ("Spawning command:\n");
                 auto argv = m_argv.get();
                 for (auto i = 0; argv[i] != NULL; i++) {
-                        vte::debug::println("    argv[{}] = {}", i, argv[i]);
+                        g_printerr("    argv[%d] = %s\n", i, argv[i]);
                 }
                 if (m_envv) {
                         auto envv = m_envv.get();
                         for (auto i = 0; envv[i] != NULL; i++) {
-                                vte::debug::println("    env[{}] = {}", i, envv[i]);
+                                g_printerr("    env[%d] = %s\n", i, envv[i]);
                         }
                 }
-                vte::debug::println("    directory: {}",
-                                    m_cwd ? m_cwd.get() : "(none)");
+                g_printerr("    directory: %s\n",
+                           m_cwd ? m_cwd.get() : "(none)");
         }
-#endif // VTE_DEBUG
 
         /* Unblock all signals */
         sigset_t set;
         sigemptyset(&set);
         if (pthread_sigmask(SIG_SETMASK, &set, nullptr) == -1) {
                 auto errsv = vte::libc::ErrnoSaver{};
-                _vte_debug_print(vte::debug::category::PTY,
-                                 "{} failed: {}",
+                _vte_debug_print(VTE_DEBUG_PTY, "%s failed: %s\n",
                                  "pthread_sigmask", g_strerror(errsv));
                 return ExecError::SIGMASK;
         }
@@ -404,11 +383,10 @@ SpawnContext::exec(vte::libc::FD& child_report_error_pipe_write,
                 /* This starts a new session; we become its process-group leader,
                  * and lose our controlling TTY.
                  */
-                _vte_debug_print(vte::debug::category::PTY, "Starting new session");
+                _vte_debug_print(VTE_DEBUG_PTY, "Starting new session\n");
                 if (setsid() == -1) {
                         auto errsv = vte::libc::ErrnoSaver{};
-                        _vte_debug_print(vte::debug::category::PTY,
-                                         "{} failed: {}",
+                        _vte_debug_print(VTE_DEBUG_PTY, "%s failed: %s\n",
                                          "setsid", g_strerror(errsv));
                         return ExecError::SETSID;
                 }
@@ -426,8 +404,7 @@ SpawnContext::exec(vte::libc::FD& child_report_error_pipe_write,
         if (!(pty()->flags() & VTE_PTY_NO_CTTY)) {
                 if (ioctl(peer_fd, TIOCSCTTY, peer_fd) != 0) {
                         auto errsv = vte::libc::ErrnoSaver{};
-                        _vte_debug_print(vte::debug::category::PTY,
-                                         "{} failed: {}",
+                        _vte_debug_print(VTE_DEBUG_PTY, "%s failed: %s\n",
                                          "ioctl(TIOCSCTTY)", g_strerror(errsv));
                         return ExecError::SCTTY;
                 }
@@ -552,7 +529,7 @@ SpawnOperation::~SpawnOperation()
 bool
 SpawnOperation::prepare(vte::glib::Error& error)
 {
-#if !WITH_SYSTEMD
+#ifndef WITH_SYSTEMD
         if (context().require_systemd_scope()) {
                 error.set_literal(G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
                                   "systemd not available");
@@ -572,7 +549,7 @@ SpawnOperation::prepare(vte::glib::Error& error)
 
         auto child_report_error_pipe_read = vte::libc::FD{};
         auto child_report_error_pipe_write = vte::libc::FD{};
-        if (!make_pipe(O_CLOEXEC,
+        if (!make_pipe(FD_CLOEXEC,
                        child_report_error_pipe_read,
                        child_report_error_pipe_write,
                        error))
@@ -736,7 +713,7 @@ SpawnOperation::run(vte::glib::Error& error) noexcept
 
         /* Spawn succeeded */
 
-#if WITH_SYSTEMD
+#ifdef WITH_SYSTEMD
         if (context().systemd_scope() &&
             !vte::systemd::create_scope_for_pid_sync(m_pid,
                                                      m_timeout, // FIXME: recalc timeout
@@ -745,8 +722,8 @@ SpawnOperation::run(vte::glib::Error& error) noexcept
                 if (context().require_systemd_scope())
                         return false;
 
-                _vte_debug_print(vte::debug::category::PTY,
-                                 "Failed to create systemd scope: {}",
+                _vte_debug_print(VTE_DEBUG_PTY,
+                                 "Failed to create systemd scope: %s",
                                  error.message());
                 error.reset();
         }
